Schedulers Module

Schedulers module for training.

class landmarker.schedulers.AdalossScheduler[source]

Scheduler for sigma parameter of gaussian heatmaps. In essence the scheduler increases the problem difficulty by decreasing the sigma parameter. Implicitly by doing this, it creates a training curriculum.

Proposed in “Adaloss: Adaptive Loss Function for Landmark Localization” - Teixeira et al.
Parameters:
  • nb_landmarks (int) – number of landmarks

  • rho (float, optional) – [description]. Defaults to 0.9.

  • window (int, optional) – [description]. Defaults to 3.

  • non_increasing (bool, optional) – [description]. Defaults to False.

__init__(nb_landmarks, rho=0.9, window=3, non_increasing=False)[source]
Parameters:
  • nb_landmarks (int)

  • rho (float)

  • window (int)

  • non_increasing (bool)